==> openmesh_9.0.orig.tar.gz: OpenMesh-9.0.0/README.md <==
# OpenMesh, 9.0

[![](https://gitlab.vci.wth-aachen.de:9000/OpenMesh/OpenMesh/badges/master/pipeline.svg)](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/commits/master)


## Getting OpenMesh
All Documentation, binaries and original source code are available at www.openmesh.org  

The main git repository is available at:  
https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh.git  

The gitlab site can be found here:  
https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh  

The python bindings can be found here:    
https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/openmesh-python

## Download Binaries

The following binaries are created from the latest master. They are automatically tested and deployed.

### Windows

| Visual Studio Version: | 2019 | 2017 |
| -------- | -------- |-------- |
| 64-Bit shared, with apps  | [Download](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2019-x64-shared-TRUE-apps) | [Download](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2017-x64-shared-TRUE-apps)  |
| 64-Bit static, with apps  | [Download ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2019-x64-shared-FALSE-apps)  | [Download ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2017-x64-shared-FALSE-apps)  |


### Apple

 [Download (Intel) ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=macos-cpp14-release)
 
 [Download (M1)    ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=macos-M1-cpp14-release)

## Download Sources
[ Download Sources](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=Sources )


## Installing
Unpack the tar-ball to a suitable place.  


A detailed build manual for Mac/Windows/Linux is in the Documentation   
located at Doc/html/index.html   

## Documentation

The latest Documentation can be found at:  
http://www.openmesh.org/media/Documentations/OpenMesh-Doc-Latest  

Documentation for previous versions is available on our website as well.

==> openmesh_10.0.0.orig.tar.gz: OpenMesh-10.0.0/README.md <==
# OpenMesh, 10.0

[![](https://gitlab.vci.wth-aachen.de:9000/OpenMesh/OpenMesh/badges/master/pipeline.svg)](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/commits/master)


## Getting OpenMesh
All Documentation, binaries and original source code are available at www.openmesh.org  

The main git repository is available at:  
https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh.git  

The gitlab site can be found here:  
https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh  

The python bindings can be found here:    
https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/openmesh-python

## Download Binaries

The following binaries are created from the latest master. They are automatically tested and deployed.

### Windows

| Visual Studio Version: | 2019 | 2017 |
| -------- | -------- |-------- |
| 64-Bit shared, with apps  | [Download](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2019-x64-shared-TRUE-apps) | [Download](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2017-x64-shared-TRUE-apps)  |
| 64-Bit static, with apps  | [Download ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2019-x64-shared-FALSE-apps)  | [Download ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=build-VS2017-x64-shared-FALSE-apps)  |


### Apple

 [Download (Intel) ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=macos-cpp14-release)
 
 [Download (M1)    ](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=macos-M1-cpp14-release)

### Debian

OpenMesh is about to get into the Debian repository. The debian packaging is available on [salsa.debian.org](https://salsa.debian.org/science-team/openmesh)


## Download Sources
[ Download Sources](https://gitlab.vci.rwth-aachen.de:9000/OpenMesh/OpenMesh/-/jobs/artifacts/master/browse?job=Sources )


## Installing
Unpack the tar-ball to a suitable place.  


A detailed build manual for Mac/Windows/Linux is in the Documentation   
located at Doc/html/index.html   

## Documentation

The latest Documentation can be found at:  
http://www.openmesh.org/media/Documentations/OpenMesh-Doc-Latest  

Documentation for previous versions is available on our website as well.
